@@ -341,7 +341,7 @@ class Taiyi:
         return set_vg
     
     def sixteen_gong(self):
-        dict1 = [{self.skyeyes:"文昌"},{self.taishui:"太歲"},{self.hegod:"合神"},{"始擊":self.sf()},
+        dict1 = [{self.skyeyes:"文昌"},{self.taishui:"太歲"},{self.hegod:"合神"},{self.sf():"始擊"},
                  {self.se():"定目"}, {self.kingbase():"君基"}, {self.officerbase():"臣基"}, {self.pplbase():"民基"},
                  {self.fgd():"四神"},{self.skyyi():"天乙"},{self.earthyi():"地乙"},{self.zhifu():"直符"},
                  {self.flyfu():"飛符"},{self.kingfu():"帝符"},{self.taijun():"太尊"}, {self.wufu():"五福"} ]
@@ -385,7 +385,7 @@ class Taiyi:
     def kingbase(self):
         kb = (self.accHour +250) % 360  / 30
         kb_v = dict(zip(range(1,13), self.new_list(Zhi, "午"))).get(int(kb))
-        if kb_v == 0 or None:
+        if kb_v == 0 or kb_v ==None:
             kb_v = "中"
         return kb_v
     
@@ -393,7 +393,7 @@ class Taiyi:
     def officerbase(self):
         ob = (self.accHour +250) % 360  % 36 / 3
         ob_v =  dict(zip(range(1,13), self.new_list(Zhi, "午"))).get(int(ob))
-        if ob_v == 0 or None:
+        if ob_v == 0 or ob_v ==None:
             ob_v = "中"
         return ob_v
     
@@ -401,7 +401,7 @@ class Taiyi:
     def pplbase(self):
         pb = (self.accHour +250) % 360 % 12
         pb_v = dict(zip(range(1,13), self.new_list(Zhi, "戌"))).get(int(pb))
-        if pb_v == 0 or None:
+        if pb_v == 0 or pb_v ==None:
             pb_v = "中"
         return  pb_v
 
@@ -413,7 +413,7 @@ class Taiyi:
         elif by > 36:
             by = by / 36
         byv = dict(zip([7,8,9,1,2,3,4,6],range(1,9))).get(int(by))
-        if byv == 0 or None:
+        if byv == 0 or byv ==None:
             byv = 5
         return byv
 
@@ -427,7 +427,7 @@ class Taiyi:
             if sy > 3:
                 sy = sy % 3
         syv = dict(zip([1,2,3,4,6,7,8,9],range(1,9))).get(int(sy))
-        if syv == 0 or None:
+        if syv == 0 or syv == None:
             syv = 5
         return syv
     
@@ -435,7 +435,7 @@ class Taiyi:
     def fgd(self):
         f = self.accHour % 360 % 36 / 3 
         fv = dict(zip(range(1,13), self.new_list(Zhi, "亥"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = "中"
         return fv
     
@@ -443,7 +443,7 @@ class Taiyi:
     def skyyi(self):
         f = self.accHour % 360 % 36 / 3 
         fv = dict(zip(range(1,13), self.new_list(Zhi, "酉"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = "中"
         return fv
 
@@ -451,7 +451,7 @@ class Taiyi:
     def earthyi(self):
         f = self.accHour % 360 % 36 / 3
         fv = dict(zip(range(1,13), self.new_list(Zhi, "巳"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = "中"
         return fv
 
@@ -459,7 +459,7 @@ class Taiyi:
     def zhifu(self):
         f = self.accHour % 360 % 36 / 3
         fv = dict(zip(range(1,14), ["中"]+self.new_list(Zhi, "酉"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = "中"
         return fv
     
@@ -467,7 +467,7 @@ class Taiyi:
     def flyfu(self):
         f = self.accHour % 360 % 36 / 3
         fv = dict(zip(range(1,13), self.new_list(Zhi, "辰"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = "中"
         return fv
     
@@ -476,16 +476,16 @@ class Taiyi:
         f = self.accHour  %20
         if f > 16:
             f = f - 16
-        elif f == 0 or None:
-            fv = "中"
         fv = dict(zip(range(1,17), self.new_list(self.gong1, "戌"))).get(int(f))
+        if fv == 0 or fv== None:
+            fv = "中"
         return fv
         
     #太尊
     def taijun(self):
         f = self.accHour  % 4
         fv = dict(zip(range(1,5), list("子午卯酉"))).get(int(f))
-        if fv == 0  or None:
+        if fv == 0  or fv == None:
             fv = "中"
         return fv
 
@@ -493,7 +493,7 @@ class Taiyi:
     def flybird(self):
         f = self.accHour  % 9
         fv = dict(zip(range(1,10), [1,8,3,4,9,2,7,6])).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv ==None:
             fv = 5
         return fv
     
@@ -502,7 +502,7 @@ class Taiyi:
         f = int(self.accHour) // 5
         f = f % 5
         fv =  dict(zip(range(1,10), [1,3,5,7,9,2,4,6,8])).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv ==None:
             fv = 5
         return fv
     
@@ -510,7 +510,7 @@ class Taiyi:
     def threewind(self):
         f = int(self.accHour) % 9
         fv = dict(zip(range(1,9), [7,2,6,1,5,9,4,8])).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = 5
         return fv
     
@@ -520,7 +520,7 @@ class Taiyi:
         if f > 10:
             f = f - 9
         fv = dict(zip(range(1,10), [1,3,5,7,9,2,4,6,8])).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = 5
         return fv
     
@@ -528,7 +528,7 @@ class Taiyi:
     def eightwind(self):
         f = int(self.accHour) % 9
         fv = dict(zip(range(1,9), [2,3,5,6,7,8,9,1])).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv == None:
             fv = 5
         return fv
     
@@ -536,7 +536,7 @@ class Taiyi:
     def wufu(self):
         f = int(self.accHour + 250) % 225 / 45 
         fv = dict(zip(range(1,6), list("乾艮巽坤中"))).get(int(f))
-        if fv == 0 or None:
+        if fv == 0 or fv ==None:
             fv = 5
         return fv
     
@@ -562,4 +562,4 @@ class Taiyi:
 
 
 if __name__ == '__main__':
-    print(Taiyi(2021,11,15,12).pan())
+    print(Taiyi(2021,11,16,10).pan())
